@@ -23,7 +23,7 @@ import click
               help='(deprecated) Maximum POI value to scan.')
 @click.option('--step', 'poi_step', type=float, default=None, 
               help='(deprecated) Scan interval.')
-@click.option('-p', '--poi', 'poi_name', default=None, show_default=True,
+@click.option('--poi', 'poi_name', default=None, show_default=True,
               help='(deprecated) POI to scan. If not specified, the first POI from the workspace is used.')
 @click.option('--cache/--no-cache', default=True, show_default=True,
               help='Cache existing result.')
