@@ -36,7 +36,7 @@ class AsymptoticCLs(AnalysisObject):
                  ws_name:Optional[str]=None, mc_name:Optional[str]=None,
                  snapshot_name:Optional[str]=None, timer:bool=False,
                  minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', 
-                 eps:float=1.0, retry:int=0, strategy:int=1, print_level:int=-1, 
+                 eps:float=1.0, retry:int=2, strategy:int=1, print_level:int=-1, 
                  num_cpu:int=1, offset:bool=True, optimize:int=2,
                  fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1,
                  max_iters:int=-1, constrain_nuis:bool=True, batch_mode:bool=False,
@@ -187,7 +187,8 @@ class AsymptoticCLs(AnalysisObject):
         if Verbosity.DEBUG >= self.stdout.verbosity:
             self.stdout.debug("DEBUG: Before Fit ----------------------------------------------")
             self.model.print_summary(items=['poi', 'nuisance_parameter', 'global_observable'])
-        self.global_status += self.minimizer.minimize(nll)
+        self.last_fit_status = self.minimizer.minimize(nll) 
+        self.global_status += self.last_fit_status
         self.minimizer_calls += 1
         nll_val = nll.getVal()
         if Verbosity.DEBUG >= self.stdout.verbosity:
@@ -210,10 +211,18 @@ class AsymptoticCLs(AnalysisObject):
         self.poi.setConstant(is_const)
         qmu = 2*(nll_value - nll_muhat)
         if qmu < 0 :
-            raise RuntimeError("qmu is negative which means the globally minimized "
-                               "NLL is larger then the NLL of interest; this can happen "
-                               "when the true global minimum is outside the valid range "
-                               "of the parameter of interest")
+            if self.last_fit_status < 0:
+                raise RuntimError("detected fit failure causing a negative qmu value;  "
+                                  "try to increase the number of retries upon a failed fit "
+                                  "(the option --retry in CLI) or check that your model can "
+                                  "accurately represent the dataset of interest")
+            else:
+                raise RuntimeError("qmu is negative which means the globally minimized "
+                                   "NLL is larger then the NLL of interest; this can happen "
+                                   "when the true global minimum is outside the valid range "
+                                   "of the parameter of interest; try to prevent automatic "
+                                   "fit range adjustment by setting adjust_fit_range to False "
+                                   "(the option --keep_fit_range in CLI)")
         return qmu
 
     def do_predictive_fit(self, nll:"ROOT.RooNLLVar", mu1:float, mu2:float, mu:float):
@@ -455,9 +464,12 @@ class AsymptoticCLs(AnalysisObject):
         self.stdout.info('Observed: {}'.format(self.limits['obs']))
         self.stdout.info('')
         
-    def save(self, filename:str='limits.json', summary=True):
+    def save(self, filename:str='limits.json', parameters:Optional[Dict]=None, summary:bool=False):
         with open(filename, "w") as file:
-            json.dump(self.limits, file, indent=2)
+            if parameters is None:
+                json.dump(self.limits, file, indent=2)
+            else:
+                json.dump({**parameters, **self.limits}, file, indent=2)
             file.truncate()
         if summary:
             data = {k:{kk:vv for kk,vv in self.summary[k].items() if kk not in ['nll', 'dataset']} \
