@@ -193,6 +193,8 @@ class ExtendedMinimizer(AbstractObject):
                     raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
             else:
                 raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
+        # fix memory leak
+        ROOT.SetOwnership(nll, True)
         return nll
             
     def create_nll(self, nll_commands:List["ROOT.RooCmdArg"]=None, 
