@@ -480,7 +480,7 @@ class ExtendedModel(AbstractObject):
         return param_dict
     
     @staticmethod
-    def randomize_globs(pdf:ROOT.RooAbsPdf, globs:ROOT.RooDataSet, seed:int):
+    def randomize_globs(pdf:ROOT.RooAbsPdf, globs:ROOT.RooArgSet, seed:int):
         """Randomize values of global observables (for generating pseudo-experiments)
         """
         # set random seed for reproducible result
