@@ -136,5 +136,9 @@ BUILTIN_METHODS = \
                "   std::iota(i.begin(), i.end(), 0);\n"
                "   std::stable_sort(i.begin(), i.end(), [&v](size_type i1, size_type i2) { return v[i1] < v[i2]; });\n"
                "   return i;\n"
-               "}\n"    
+               "}\n"
+               "Double_t Phi_mpi_pi(Double_t x)\n"
+               "{\n"
+               "   return TVector2::Phi_mpi_pi(x);\n"
+               "}\n"
 }
\ No newline at end of file
