@@ -2,6 +2,9 @@ from enum import Enum
 
 class GeneralEnum(Enum):
     
+    __aliases__ = {
+    }
+
     @classmethod
     def on_parse_exception(cls, expr:str):
         options = cls.get_members()
@@ -15,6 +18,8 @@ class GeneralEnum(Enum):
         _expr = expr.strip().upper()
         if _expr in cls.__members__:
             return cls[_expr]
+        elif _expr in cls.__aliases__:
+            return cls(cls.__aliases__[_expr])
         else:
             cls.on_parse_exception(expr)
             
