@@ -80,7 +80,7 @@ def approx_n_digit(val:float, default=5):
     else:
         return 0
 
-def str_encode_value(val, n_digit=None, formatted=True):
+def str_encode_value(val:float, n_digit=None, formatted=True):
     # account for the case where val is negative zero
     if round(float(val), 8) == 0:
         val = 0.
@@ -89,7 +89,7 @@ def str_encode_value(val, n_digit=None, formatted=True):
         #if val_str == '-{{:.{}f}}'.format(n_digit).format(0):
         #    val_str = '{{:.{}f}}'.format(n_digit).format(0)
     else:
-        val_str = str(val)
+        val_str = str(float(val))
     
     if formatted:
         val_str = val_str.replace('.', 'p').replace('-', 'n')
