@@ -31,7 +31,7 @@ class AbstractPlot:
                  figure_index:Optional[int]=None,
                  config:Optional[Dict]=None):
         
-        self.color_pallete = combine_dict(self.COLOR_PALLETE, color_pallete)
+        self.color_pallete     = combine_dict(self.COLOR_PALLETE, color_pallete)
         self.color_pallete_sec = combine_dict(self.COLOR_PALLETE_SEC, color_pallete_sec)
             
         self.styles = combine_dict(self.STYLES, styles)
@@ -65,8 +65,8 @@ class AbstractPlot:
             
         self.annotation_list = []
         
-    def add_annotation(self, **kwargs):
-        self.annotation_list.append(kwargs)
+    def add_annotation(self, text:str, **kwargs):
+        self.annotation_list.append({"text": text, **kwargs})
         
     def get_default_legend_order(self):
         return []
@@ -129,7 +129,7 @@ class AbstractPlot:
                         labels.append(label)
         return handles, labels
     
-    def draw_frame(self, frame_method=None, **kwargs):
+    def draw_frame(self, frame_method:Callable=None, **kwargs):
         if frame_method is None:
             frame_method = single_frame
         ax = frame_method(styles=self.styles,
@@ -138,11 +138,11 @@ class AbstractPlot:
                           figure_index=self.figure_index,
                           **kwargs)
         for annotation_kwargs in self.annotation_list:
-            _annotation_kwargs = combine_dict(self.styles['annotation'], annotation_kwargs)
+            annotation_kwargs = combine_dict(self.styles['annotation'], annotation_kwargs)
             if isinstance(ax, tuple):
-                ax[0].annotate(**_annotation_kwargs)
+                ax[0].annotate(**annotation_kwargs)
             else:
-                ax.annotate(**_annotation_kwargs)
+                ax.annotate(**annotation_kwargs)
         self.figure = matplotlib.pyplot.gcf()
         return ax
     
@@ -173,7 +173,8 @@ class AbstractPlot:
         if xlim is not None:
             ax.set_xlim(*xlim)
     
-    def set_axis_range(self, ax, xmin:Optional[float]=None, xmax:Optional[float]=None,
+    def set_axis_range(self, ax,
+                       xmin:Optional[float]=None, xmax:Optional[float]=None,
                        ymin:Optional[float]=None, ymax:Optional[float]=None,
                        ypad:Optional[float]=None):
         xlim = list(ax.get_xlim())
@@ -183,8 +184,8 @@ class AbstractPlot:
         if xmax is not None:
             xlim[1] = xmax
         if ypad is not None:
-            if (ymin is not None) or (ymax is not None):
-                raise ValueError('can not use both "ypad" and "ymin"/"ymax" when setting axis range')
+            if (ymax is not None):
+                raise ValueError('can not use both "ypad" and "ymax" when setting axis range')
             if ypad < 0 or ypad > 1:
                 raise ValueError('"ypad" must be between 0 and 1')
             ylim[1] = ylim[1] / (1 - ypad)
