@@ -49,7 +49,8 @@ class PdfDistributionPlot(AbstractPlot):
         }        
     }
     
-    def __init__(self, collective_data:Dict, blind_range:Optional[List[float]]=None,
+    def __init__(self, collective_data:Dict,
+                 blind_range:Optional[List[float]]=None,
                  plot_options:Optional[Dict]=None,
                  scale_map:Optional[Dict]=None,
                  label_map:Optional[Dict]=None,
@@ -265,10 +266,22 @@ class PdfDistributionPlot(AbstractPlot):
             raise RuntimeError("cannot compare two distributions with different binnings")
         pdata_comp = {}
         pdata_comp['x'] = pdata_ref['x']
-        if pdata_tgt['yerr'] is not None:
-            raise RuntimeError("target distribution must be a pdf (i.e. no error information)")
-        pdata_comp['yerr'] = pdata_ref['yerr']
+        pdata_comp['yerr'] = 0
         pdata_comp['xerr'] = pdata_ref['xerr']
+        if pdata_ref['yerr'] is None:
+            if isinstance(pdata_tgt['yerr'], tuple):
+                yerr_ref = (np.zeros(pdata_ref['y'].shape), np.zeros(pdata_ref['y'].shape))
+            else:
+                yerr_ref = np.zeros(pdata_ref['y'].shape)
+        else:
+             yerr_ref = pdata_ref['yerr']
+        if pdata_tgt['yerr'] is None:
+            if isinstance(pdata_ref['yerr'], tuple):
+                yerr_tgt = (np.zeros(pdata_tgt['y'].shape), np.zeros(pdata_tgt['y'].shape))
+            else:
+                yerr_tgt = np.zeros(pdata_tgt['y'].shape)
+        else:
+             yerr_tgt = pdata_tgt['yerr']
         if mode == "ratio":
             vmode = 0
         elif mode in ["diff", "difference"]:
@@ -276,15 +289,21 @@ class PdfDistributionPlot(AbstractPlot):
         else:
             raise ValueError(f"unsupported mode \"{mode}\", choose between \"ratio\" and \"difference\"")
         if vmode == 0:
-            pdata_comp['y'] = pdata_ref['y'] / pdata_tgt['y']
-            if pdata_ref['yerr'] is not None:
-                if isinstance(pdata_ref['yerr'], tuple):
-                    pdata_comp['yerr'] = (pdata_ref['yerr'][0] / pdata_tgt['y'], 
-                                          pdata_ref['yerr'][1] / pdata_tgt['y'])
-                else:
-                    pdata_comp['yerr'] = pdata_ref['yerr'] / pdata_tgt['y']
+            pdata_comp['y'] = pdata_tgt['y'] / pdata_ref['y']
+            if isinstance(yerr_ref, tuple):
+                errlo = np.sqrt((yerr_ref[0]/pdata_ref['y'])**2 + (yerr_tgt[0]/pdata_tgt['y'])**2)
+                errhi = np.sqrt((yerr_ref[1]/pdata_ref['y'])**2 + (yerr_tgt[1]/pdata_tgt['y'])**2)
+                pdata_comp['yerr'] = (errlo, errhi)
+            else:
+                pdata_comp['yerr'] = np.sqrt((yerr_ref/pdata_ref['y'])**2 + (yerr_tgt/pdata_tgt['y'])**2)
         elif vmode == 1:
-            pdata_comp['y'] = pdata_ref['y'] - pdata_tgt['y']
+            pdata_comp['y'] = pdata_tgt['y'] - pdata_ref['y']
+            if isinstance(yerr_ref, tuple):
+                errlo = np.sqrt(yerr_ref[0]**2 + yerr_tgt[0]**2)
+                errhi = np.sqrt(yerr_ref[1]**2 + yerr_tgt[1]**2)
+                pdata_comp['yerr'] = (errlo, errhi)
+            else:
+                pdata_comp['yerr'] = np.sqrt(yerr_ref**2 + yerr_tgt**2)
             
         combined_options = combine_dict(plot_options)
         if combined_options.get('markersize', None) is None:
@@ -305,7 +324,6 @@ class PdfDistributionPlot(AbstractPlot):
             
         if not show_error:
             error_format = None
-            
         handle = self._draw_data(ax, x, y, xerr, yerr,
                                  plot_options=combined_options,
                                  error_format=error_format,
@@ -330,9 +348,9 @@ class PdfDistributionPlot(AbstractPlot):
                 ax.axhline(0, zorder=0, **ratio_linestyles)
         if not ylabel:
             if vmode == 0:
-                ylabel = "Data / Fit"
+                ylabel = "Fit / Data"
             elif vmode == 1:
-                ylabel = "Data - Fit"
+                ylabel = "Fit - Data"
             else:
                 ylabel = ""
         self.draw_axis_components(ax, xlabel=xlabel, ylabel=ylabel)
@@ -340,7 +358,7 @@ class PdfDistributionPlot(AbstractPlot):
     
     def set_annotation(self, params:Optional[Dict]=None,
                        stats:Optional[Dict]=None,
-                       val_fmt:str="{:.3f}",
+                       val_fmt:str="{:.2f}",
                        **styles):
         text = ""
         if params:
@@ -374,7 +392,10 @@ class PdfDistributionPlot(AbstractPlot):
              logx:bool=False, logy:bool=False,
              blind_range:Optional[List[float]]=None,
              show_error:bool=True,
-             comparison_options:Optional[Union[Dict, List[Dict]]]=None):
+             comparison_options:Optional[Union[Dict, List[Dict]]]=None,
+             xmin:Optional[float]=None, xmax:Optional[float]=None,
+             ymin:Optional[float]=None, ymax:Optional[float]=None,
+             ypad:Optional[float]=None):
         
         if comparison_options is not None:
             ax, ax_ratio = self.draw_frame(ratio_frames, logx=logx, logy=logy,
@@ -417,8 +438,9 @@ class PdfDistributionPlot(AbstractPlot):
                     self.colors[name] = handle.get_color()
                 else:
                     self.colors[name] = handle[0].get_color()
-        
+
         self.draw_axis_components(ax, xlabel=xlabel, ylabel=ylabel)
+        self.set_axis_range(ax, xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax, ypad=ypad)  
         handles, labels = self.get_legend_handles_labels()
         ax.legend(handles, labels, **self.styles['legend'])
         
@@ -431,9 +453,12 @@ class PdfDistributionPlot(AbstractPlot):
                 mode      = options.get('mode', "ratio")
                 ylabel    = options.get('label', "")
                 labelsize = options.get('labelsize', None)
+                styles    = options.get('styles', {})
                 draw_ratio_line = options.get('draw_ratio_line', True)
                 plot_options = self.plot_options.get(reference, {})
-                plot_options['color'] = self.colors[reference]
+                if ('color' not in plot_options) and (target in self.colors):
+                    plot_options['color'] = self.colors[target]
+                plot_options.update(styles)
                 if (reference not in self.error_options) or \
                    (self.error_options[reference]["display_format"] is None):
                     error_format = None
@@ -465,3 +490,31 @@ class PdfDistributionPlot(AbstractPlot):
             return ax, ax_ratio
         
         return ax
+
+    @classmethod
+    def from_roofit_data(cls, data:"ROOT.RooDataSet",
+                         pdf:Optional["ROOT.RooAbsPdf"]=None,
+                         observable:Optional["ROOT.RooRealVar"]=None,
+                         bin_range:Optional[List]=None,
+                         bin_error:bool=True,
+                         n_bins_data:Optional[int]=None,
+                         n_bins_pdf:Optional[int]=1000,
+                         blind_range:Optional[List[float]]=None,
+                         label_map:Optional[Dict]=None,
+                         color_cycle:Optional[Dict]=None,
+                         styles:Optional[Union[Dict, str]]=None,
+                         analysis_label_options:Optional[Union[Dict, str]]=None,
+                         figure_index:Optional[int]=None,
+                         config:Optional[Dict]=None):
+        from quickstats.utils.roofit_utils import export_hist_data
+        hist_data = export_hist_data(data, pdf,
+                                     observable=observable,
+                                     bin_range=bin_range,
+                                     bin_error=bin_error,
+                                     n_bins_data=n_bins_data,
+                                     n_bins_pdf=n_bins_pdf)
+        plotter = cls(hist_data, blind_range=blind_range,
+                      label_map=label_map, color_cycle=color_cycle,
+                      styles=styles, analysis_label_options=analysis_label_options,
+                      figure_index=figure_index, config=config)
+        return plotter
\ No newline at end of file
