@@ -210,6 +210,30 @@ def format_delimiter_enclosed_text(text:str, delimiter:str, width:int=10, indent
 def insert_periodic_substr(s:str, every:int=64, substr:str='\n'):
     return substr.join(s[i:i+every] for i in range(0, len(s), every))
         
+def format_display_string(s:str, indent:str="", linebreak:int=80, skipfirst:bool=False):
+    if len(indent) >= linebreak:
+        raise RuntimeError("size of indentation is greater linebreak")
+    substr = "\n" + indent
+    every = linebreak - len(indent)
+    ss = insert_periodic_substr(s, every, substr)
+    if not skipfirst:
+        return indent + ss
+    return ss
+
+def itemize_dict(d:Dict, separator:str=": ", leftmargin:int=0, linebreak:int=100):
+    max_key_size = max([len(k) for k in d.keys()])
+    bullet_size = max_key_size + len(separator)
+    indent_size = leftmargin + bullet_size
+    text_size = linebreak - indent_size
+    if text_size <= 0:
+        raise RuntimeError("size of indentation is greater linebreak")
+    texts = []
+    substr = "\n" + " " * indent_size
+    for k, v in d.items():
+        v = v.replace("\n", "")
+        text = "{0:>{1}}".format(k + separator, indent_size) + insert_periodic_substr(v, text_size, substr)
+        texts.append(text)
+    return "\n".join(texts) + "\n"
 
 def filter_by_wildcards(targets:List, conditions:Optional[Union[str, List]]=None, exclusion:bool=False):
     if not conditions:
@@ -226,4 +250,15 @@ def filter_by_wildcards(targets:List, conditions:Optional[Union[str, List]]=None
 
 def set_unlimited_stacksize():
     import resource
-    resource.setrlimit(resource.RLIMIT_STACK, (resource.RLIM_INFINITY, resource.RLIM_INFINITY))
\ No newline at end of file
+    resource.setrlimit(resource.RLIMIT_STACK, (resource.RLIM_INFINITY, resource.RLIM_INFINITY))
+    
+def in_notebook():
+    try:
+        from IPython import get_ipython
+        if 'IPKernelApp' not in get_ipython().config:  # pragma: no cover
+            return False
+    except ImportError:
+        return False
+    except AttributeError:
+        return False
+    return True
\ No newline at end of file
