@@ -1,4 +1,5 @@
 from typing import Union, Optional, Dict, List, Set
+import uuid
 
 import ROOT
 
@@ -51,8 +52,8 @@ def variable_collection_to_dataframe(var_collection:Union[list, ROOT.RooArgSet],
     return df
         
 def construct_categorized_pdf_dataset(pdf:"ROOT.RooAbsPdf", dataset:"ROOT.RooDataSet", 
-                               workspace:"ROOT.RooWorkspace", label:str,
-                               category_name:str="adhocCat"):
+                                      workspace:"ROOT.RooWorkspace", label:str,
+                                      category_name:str="adhocCat"):
     # make sure pdf is not already a simultaneous pdf
     assert pdf.ClassName() != "RooSimultaneous"
     cat = ROOT.RooCategory(category_name, category_name)
@@ -184,8 +185,6 @@ def rebuild_simultaneous_pdf(observables:"ROOT.RooArgSet", sim_pdf:"ROOT.RooSimu
     copy_attributes(sim_pdf, rebuilt_pdf)
     return rebuilt_pdf
 
-
-
 def print_object(obj, indent=0, spacer="  ", prefix="-", show_address=False):
     if show_address:
         print(f"{spacer*indent}{prefix}{obj.GetName()}({obj.ClassName()} @ {hex(id(obj))})")
@@ -241,4 +240,75 @@ def get_relevant_components(target, reference:Set[ROOT.RooArgSet]):
         for component in components:
             relevant_components = get_relevant_components(component, reference)
             result.add(relevant_components)
-    return result
\ No newline at end of file
+    return result
+
+def export_hist_data(data:ROOT.RooDataSet,
+                     pdf:Optional[ROOT.RooAbsPdf]=None,
+                     observable:Optional[ROOT.RooRealVar]=None,
+                     bin_range:Optional[List]=None,
+                     bin_error:bool=True,
+                     n_bins_data:Optional[int]=None,
+                     n_bins_pdf:Optional[int]=1000):
+
+    if observable is None:
+        if data.get().size() > 1:
+            raise RuntimeError("only single-observable is allowed")
+        observable = data.get().first()
+
+    if bin_range is None:
+        bin_range = observable.getRange()
+        bin_range = [bin_range.first, bin_range.second]
+
+    if n_bins_data is None:
+        n_bins_data = observable.getBins()
+        
+    if n_bins_pdf is None:
+        n_bins_pdf = n_bins_data        
+        
+    binning_data = ROOT.RooFit.Binning(n_bins_data, bin_range[0], bin_range[1])
+    binning_pdf  = ROOT.RooFit.Binning(n_bins_pdf, bin_range[0], bin_range[1])
+
+    from quickstats.interface.root import RooAbsData
+    h_data = RooAbsData.create_histogram(data, uuid.uuid4().hex, observable, binning_data)
+    
+    if bin_error:
+        # use SumW2 error if weighted, else use Poisson error
+        if data.isWeighted():
+            bin_errors = {"lo": h_data.bin_error, "hi": h_data.bin_error}
+        else:
+            from quickstats.interface.root import TH1
+            bin_errors = TH1.GetPoissonError(h_data.bin_content)
+    else:
+        size = len(h_data.bin_content)
+        bin_errors = {"lo": np.zeros(size), "hi": np.zeros(size)}
+
+    hist_data = {
+        'data': {
+            'x': h_data.bin_center,
+            'y': h_data.bin_content,
+            'yerrlo': bin_errors['lo'],
+            'yerrhi': bin_errors['hi']
+        }
+    }
+    
+    if pdf is not None:
+        
+        h_pdf = RooAbsData.create_histogram(pdf, uuid.uuid4().hex, observable, binning_pdf)
+        h_pdf_data_binning = RooAbsData.create_histogram(pdf, uuid.uuid4().hex, observable,
+                                                         binning_data)
+        
+        # calculate normalization factors
+        norm_data  = h_data.bin_content.sum()
+        norm_pdf1  = h_pdf.bin_content.sum()
+        norm_pdf2  = h_pdf_data_binning.bin_content.sum()            
+            
+        hist_data['pdf'] = {
+            'x': h_pdf.bin_center,
+            'y': h_pdf.bin_content * norm_data / norm_pdf1 * (n_bins_pdf / n_bins_data)
+        }
+        hist_data['pdf_data_binning'] = {
+            'x': h_pdf_data_binning.bin_center,
+            'y': h_pdf_data_binning.bin_content * norm_data / norm_pdf2
+        }
+        
+    return hist_data
\ No newline at end of file
